@@ -9,25 +9,25 @@ use Data::Object 'Class';
 
 extends 'Data::Object::Array::Func';
 
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 # BUILD
 
 has arg1 => (
   is => 'ro',
-  isa => 'Object',
+  isa => 'ArrayLike',
   req => 1
 );
 
 has arg2 => (
   is => 'ro',
-  isa => 'Num',
+  isa => 'NumberLike',
   req => 1
 );
 
 has arg3 => (
   is => 'ro',
-  isa => 'CodeRef',
+  isa => 'CodeLike',
   req => 1
 );
 
@@ -126,25 +126,25 @@ This package has the following attributes.
 
 =head2 arg1
 
-  arg1(Object)
+  arg1(ArrayLike)
 
-The attribute is read-only, accepts C<(Object)> values, and is optional.
+The attribute is read-only, accepts C<(ArrayLike)> values, and is optional.
 
 =cut
 
 =head2 arg2
 
-  arg2(Num)
+  arg2(NumberLike)
 
-The attribute is read-only, accepts C<(Num)> values, and is optional.
+The attribute is read-only, accepts C<(NumberLike)> values, and is optional.
 
 =cut
 
 =head2 arg3
 
-  arg3(CodeRef)
+  arg3(CodeLike)
 
-The attribute is read-only, accepts C<(CodeRef)> values, and is optional.
+The attribute is read-only, accepts C<(CodeLike)> values, and is optional.
 
 =cut
 
@@ -206,7 +206,7 @@ Returns the ordered list of named function object arguments.
 
 =head1 CREDITS
 
-Al Newkirk, C<+289>
+Al Newkirk, C<+294>
 
 Anthony Brummett, C<+10>
 
