@@ -9,19 +9,19 @@ use Data::Object 'Class';
 
 extends 'Data::Object::Array::Func';
 
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 # BUILD
 
 has arg1 => (
   is => 'ro',
-  isa => 'Object',
+  isa => 'ArrayLike',
   req => 1
 );
 
 has arg2 => (
   is => 'ro',
-  isa => 'Undef | CodeRef',
+  isa => 'Undef | UndefObject | CodeLike',
   opt => 1
 );
 
@@ -114,17 +114,17 @@ This package has the following attributes.
 
 =head2 arg1
 
-  arg1(Object)
+  arg1(ArrayLike)
 
-The attribute is read-only, accepts C<(Object)> values, and is optional.
+The attribute is read-only, accepts C<(ArrayLike)> values, and is optional.
 
 =cut
 
 =head2 arg2
 
-  arg2(Undef | CodeRef)
+  arg2(Undef | UndefObject | CodeLike)
 
-The attribute is read-only, accepts C<(Undef | CodeRef)> values, and is optional.
+The attribute is read-only, accepts C<(Undef | UndefObject | CodeLike)> values, and is optional.
 
 =cut
 
@@ -182,7 +182,7 @@ Returns the ordered list of named function object arguments.
 
 =head1 CREDITS
 
-Al Newkirk, C<+289>
+Al Newkirk, C<+294>
 
 Anthony Brummett, C<+10>
 
