@@ -9,19 +9,19 @@ use Data::Object 'Class';
 
 extends 'Data::Object::Code::Func';
 
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 # BUILD
 
 has arg1 => (
   is => 'ro',
-  isa => 'Object',
+  isa => 'CodeLike',
   req => 1
 );
 
 has arg2 => (
   is => 'ro',
-  isa => 'CodeRef',
+  isa => 'CodeLike',
   req => 1
 );
 
@@ -95,17 +95,17 @@ This package has the following attributes.
 
 =head2 arg1
 
-  arg1(Object)
+  arg1(CodeLike)
 
-The attribute is read-only, accepts C<(Object)> values, and is optional.
+The attribute is read-only, accepts C<(CodeLike)> values, and is optional.
 
 =cut
 
 =head2 arg2
 
-  arg2(CodeRef)
+  arg2(CodeLike)
 
-The attribute is read-only, accepts C<(CodeRef)> values, and is optional.
+The attribute is read-only, accepts C<(CodeLike)> values, and is optional.
 
 =cut
 
@@ -156,7 +156,7 @@ Returns the ordered list of named function object arguments.
 
 =head1 CREDITS
 
-Al Newkirk, C<+289>
+Al Newkirk, C<+294>
 
 Anthony Brummett, C<+10>
 
