@@ -9,13 +9,13 @@ use Data::Object 'Class';
 
 extends 'Data::Object::Float::Func';
 
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 # BUILD
 
 has arg1 => (
   is => 'ro',
-  isa => 'Object',
+  isa => 'NumberLike',
   req => 1
 );
 
@@ -100,9 +100,9 @@ This package has the following attributes.
 
 =head2 arg1
 
-  arg1(Object)
+  arg1(NumberLike)
 
-The attribute is read-only, accepts C<(Object)> values, and is optional.
+The attribute is read-only, accepts C<(NumberLike)> values, and is optional.
 
 =cut
 
@@ -161,7 +161,7 @@ Returns the ordered list of named function object arguments.
 
 =head1 CREDITS
 
-Al Newkirk, C<+289>
+Al Newkirk, C<+294>
 
 Anthony Brummett, C<+10>
 
