@@ -9,19 +9,19 @@ use Data::Object 'Class';
 
 extends 'Data::Object::Hash::Func';
 
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 # BUILD
 
 has arg1 => (
   is => 'ro',
-  isa => 'Object',
+  isa => 'HashLike',
   req => 1
 );
 
 has arg2 => (
   is => 'ro',
-  isa => 'Str',
+  isa => 'StringLike',
   req => 1
 );
 
@@ -103,9 +103,9 @@ The attribute is read-only, accepts C<(Object)> values, and is optional.
 
 =head2 arg2
 
-  arg2(Num)
+  arg2(NumberLike)
 
-The attribute is read-only, accepts C<(Num)> values, and is optional.
+The attribute is read-only, accepts C<(NumberLike)> values, and is optional.
 
 =cut
 
@@ -156,7 +156,7 @@ Returns the ordered list of named function object arguments.
 
 =head1 CREDITS
 
-Al Newkirk, C<+289>
+Al Newkirk, C<+294>
 
 Anthony Brummett, C<+10>
 
