@@ -9,13 +9,13 @@ use Data::Object 'Class';
 
 extends 'Data::Object::Hash::Func';
 
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 # BUILD
 
 has arg1 => (
   is => 'ro',
-  isa => 'Object',
+  isa => 'HashLike',
   req => 1
 );
 
@@ -107,9 +107,9 @@ The attribute is read-only, accepts C<(Object)> values, and is optional.
 
 =head2 args
 
-  args(ArrayRef[Str])
+  args(ArrayRef[StringLike])
 
-The attribute is read-only, accepts C<(ArrayRef[Str])> values, and is optional.
+The attribute is read-only, accepts C<(ArrayRef[StringLike])> values, and is optional.
 
 =cut
 
@@ -160,7 +160,7 @@ Returns the ordered list of named function object arguments.
 
 =head1 CREDITS
 
-Al Newkirk, C<+289>
+Al Newkirk, C<+294>
 
 Anthony Brummett, C<+10>
 
