@@ -9,31 +9,31 @@ use Data::Object 'Class';
 
 extends 'Data::Object::Hash::Func';
 
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 # BUILD
 
 has arg1 => (
   is => 'ro',
-  isa => 'Object',
+  isa => 'HashLike',
   req => 1
 );
 
 has arg2 => (
   is => 'ro',
-  isa => 'Str',
+  isa => 'StringLike',
   opt => 1
 );
 
 has arg3 => (
   is => 'ro',
-  isa => 'HashRef',
+  isa => 'HashLike',
   opt => 1
 );
 
 has arg4 => (
   is => 'ro',
-  isa => 'HashRef',
+  isa => 'HashLike',
   opt => 1
 );
 
@@ -161,25 +161,25 @@ The attribute is read-only, accepts C<(Object)> values, and is optional.
 
 =head2 arg2
 
-  arg2(Str)
+  arg2(StringLike)
 
-The attribute is read-only, accepts C<(Str)> values, and is optional.
+The attribute is read-only, accepts C<(StringLike)> values, and is optional.
 
 =cut
 
 =head2 arg3
 
-  arg3(HashRef)
+  arg3(HashLike)
 
-The attribute is read-only, accepts C<(HashRef)> values, and is optional.
+The attribute is read-only, accepts C<(HashLike)> values, and is optional.
 
 =cut
 
 =head2 arg4
 
-  arg4(HashRef)
+  arg4(HashLike)
 
-The attribute is read-only, accepts C<(HashRef)> values, and is optional.
+The attribute is read-only, accepts C<(HashLike)> values, and is optional.
 
 =cut
 
@@ -229,7 +229,7 @@ Returns the ordered list of named function object arguments.
 
 =head1 CREDITS
 
-Al Newkirk, C<+289>
+Al Newkirk, C<+294>
 
 Anthony Brummett, C<+10>
 
