@@ -7,12 +7,13 @@ use warnings;
 
 use base 'Type::Library';
 
+use Scalar::Util ();
+use Type::Coercion ();
 use Type::Tiny ();
 use Type::Utils ();
-use Type::Coercion ();
 use Types::TypeTiny ();
 
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 Type::Utils::extends('Types::Standard');
 Type::Utils::extends('Types::TypeTiny');
@@ -728,6 +729,17 @@ sub GenerateExplanation {
   return $type->{explaination}->($_[2], $_[1], $_[3]);
 }
 
+# ONE-OFFS
+
+Type::Utils::declare('RegexpLike', Type::Utils::as(Object(), Type::Utils::where(sub {
+  return !!re::is_regexp($_[0]) || (Scalar::Util::blessed($_[0]) &&
+    ($_[0]->isa('Regexp') || $_[0]->isa('Data::Object::Regexp')));
+})));
+
+Type::Utils::declare('NumberLike', Type::Utils::as(StringLike(), Type::Utils::where(sub {
+  return Scalar::Util::looks_like_number("$_[0]");
+})));
+
 1;
 
 =encoding utf8
@@ -1889,6 +1901,17 @@ used to throw an exception if the argument can not be validated. The C<is_Num>
 function can be used to return true or false if the argument can not be
 validated.
 
+=head2 numberlike
+
+  # NumberLike
+
+The C<NumberLike> type constraint is provided by the this library and accepts
+any value that looks like a number, or object that overloads stringification
+and looks like a number stringified. Please see that documentation for more
+information. The C<assert_NumberLike> function can be used to throw an
+exception if the argument can not be validated. The C<is_NumberLike> function
+can be used to return true or false if the argument can not be validated.
+
 =head2 numobj
 
   # NumObj
@@ -2474,7 +2497,7 @@ can not be validated. The C<is_VarsObject> function can be used to return true
 
 =head1 CREDITS
 
-Al Newkirk, C<+289>
+Al Newkirk, C<+294>
 
 Anthony Brummett, C<+10>
 
