@@ -11,19 +11,19 @@ use Data::Object::Search;
 
 extends 'Data::Object::Regexp::Func';
 
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 # BUILD
 
 has arg1 => (
   is => 'ro',
-  isa => 'Object',
+  isa => 'RegexpLike',
   req => 1
 );
 
 has arg2 => (
   is => 'ro',
-  isa => 'Str',
+  isa => 'StringLike',
   req => 1
 );
 
@@ -117,17 +117,17 @@ This package has the following attributes.
 
 =head2 arg1
 
-  arg1(Object)
+  arg1(RegexpLike)
 
-The attribute is read-only, accepts C<(Object)> values, and is optional.
+The attribute is read-only, accepts C<(RegexpLike)> values, and is optional.
 
 =cut
 
 =head2 arg2
 
-  arg2(Str)
+  arg2(StringLike)
 
-The attribute is read-only, accepts C<(Str)> values, and is optional.
+The attribute is read-only, accepts C<(StringLike)> values, and is optional.
 
 =cut
 
@@ -178,7 +178,7 @@ Returns the ordered list of named function object arguments.
 
 =head1 CREDITS
 
-Al Newkirk, C<+289>
+Al Newkirk, C<+294>
 
 Anthony Brummett, C<+10>
 
