@@ -9,13 +9,13 @@ use Data::Object 'Class';
 
 extends 'Data::Object::String::Func';
 
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 # BUILD
 
 has arg1 => (
   is => 'ro',
-  isa => 'Object',
+  isa => 'StringLike',
   req => 1
 );
 
@@ -96,17 +96,17 @@ This package has the following attributes.
 
 =head2 arg1
 
-  arg1(Object)
+  arg1(StringLike)
 
-The attribute is read-only, accepts C<(Object)> values, and is optional.
+The attribute is read-only, accepts C<(StringLike)> values, and is optional.
 
 =cut
 
 =head2 args
 
-  args(ArrayRef[Str])
+  args(ArrayRef[StringLike])
 
-The attribute is read-only, accepts C<(ArrayRef[Str])> values, and is optional.
+The attribute is read-only, accepts C<(ArrayRef[StringLike])> values, and is optional.
 
 =cut
 
@@ -157,7 +157,7 @@ Returns the ordered list of named function object arguments.
 
 =head1 CREDITS
 
-Al Newkirk, C<+289>
+Al Newkirk, C<+294>
 
 Anthony Brummett, C<+10>
 
