@@ -9,19 +9,19 @@ use Data::Object 'Class';
 
 extends 'Data::Object::String::Func';
 
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 # BUILD
 
 has arg1 => (
   is => 'ro',
-  isa => 'Object',
+  isa => 'StringLike',
   req => 1
 );
 
 has arg2 => (
   is => 'ro',
-  isa => 'Str | RegexpRef',
+  isa => 'StringLike | RegexpLike',
   req => 1
 );
 
@@ -102,17 +102,17 @@ This package has the following attributes.
 
 =head2 arg1
 
-  arg1(Object)
+  arg1(StringLike)
 
-The attribute is read-only, accepts C<(Object)> values, and is optional.
+The attribute is read-only, accepts C<(StringLike)> values, and is optional.
 
 =cut
 
 =head2 arg2
 
-  arg2(Str | RegexpRef)
+  arg2(StringLike | RegexpLike)
 
-The attribute is read-only, accepts C<(Str | RegexpRef)> values, and is optional.
+The attribute is read-only, accepts C<(StringLike | RegexpLike)> values, and is optional.
 
 =cut
 
@@ -163,7 +163,7 @@ Returns the ordered list of named function object arguments.
 
 =head1 CREDITS
 
-Al Newkirk, C<+289>
+Al Newkirk, C<+294>
 
 Anthony Brummett, C<+10>
 
