@@ -9,26 +9,26 @@ use Data::Object 'Class';
 
 extends 'Data::Object::String::Func';
 
-our $VERSION = '1.74'; # VERSION
+our $VERSION = '1.75'; # VERSION
 
 # BUILD
 
 has arg1 => (
   is => 'ro',
-  isa => 'Object',
+  isa => 'StringLike',
   req => 1
 );
 
 has arg2 => (
   is => 'ro',
-  isa => 'RegexpRef | Str',
+  isa => 'RegexpLike | StringLike',
   def => sub { qr() },
   opt => 1
 );
 
 has arg3 => (
   is => 'ro',
-  isa => 'Num',
+  isa => 'NumberLike',
   opt => 1
 );
 
@@ -108,17 +108,17 @@ This package has the following attributes.
 
 =head2 arg1
 
-  arg1(Object)
+  arg1(StringLike)
 
-The attribute is read-only, accepts C<(Object)> values, and is optional.
+The attribute is read-only, accepts C<(StringLike)> values, and is optional.
 
 =cut
 
 =head2 arg3
 
-  arg3(Num)
+  arg3(NumberLike)
 
-The attribute is read-only, accepts C<(Num)> values, and is optional.
+The attribute is read-only, accepts C<(NumberLike)> values, and is optional.
 
 =cut
 
@@ -170,7 +170,7 @@ Returns the ordered list of named function object arguments.
 
 =head1 CREDITS
 
-Al Newkirk, C<+289>
+Al Newkirk, C<+294>
 
 Anthony Brummett, C<+10>
 
